<?php

require "config.inc.php";
require "ldapfunc.inc.php";
require "general.inc.php";

/* {{{ createIconsHash() creates an associative array which maps entry
	types to their matching icon filenames
*/
function createIconsHash($entry_types, &$icons) {

	foreach (array_keys($entry_types) as $key) {
		if (file_exists(IMAGES_PATH."/".$key.".png")) {
			$icons[$key] = $key.".png";

			if (file_exists(IMAGES_PATH."/open_".$key.".png"))
				$icons["open_".$key] = "open_".$key.".png";
		}
	}

}

function showContents($ldap_func, $base_dn) {
	global $expand, $collapse;
	global $icons; # Associative array mapping group names to icon files

	$sr = ldap_list($ldap_func->ldap_conn, $base_dn, "(objectClass=*)", array("dn", "objectclass"));

	$info = ldap_get_entries($ldap_func->ldap_conn, $sr);
	if (!$info["count"]) return;

	# First let's sort the list of DNs
	for ($i = 0; $i < $info["count"]; $i++) {
		$DNs[$i] = $info[$i]["dn"];

		for ($j = 0; $j < $info[$i]["objectclass"]["count"]; $j++)
			$objectclasses[$DNs[$i]][$j] = $info[$i]["objectclass"][$j];
	}
	sort($DNs, SORT_STRING);

	echo "<TABLE BORDER=\"0\" CELLSPACING=\"0\" CELLPADDING=\"0\">";

	for ($i = 0; $i < count($DNs); $i++) {
		$dn = $DNs[$i];

		# Find out what the objectclass group is
		$group = getEntryType($objectclasses[$dn]);

		if (ereg("^([^\,]+)", $dn, $regs))
			$rdn = $regs[1];
		else
			die("Invalid dn $dn!");

		# If this is the currently-changed-status (active) entry
		if ($dn == $collapse || $dn == $expand) {
			$anchor = "<A NAME=\"activeentry\"></A>";
			$selected = "_selected";
		}
		else {
			$anchor = "";
			$selected = "";
		}

		if ($_SESSION["expanded"][$dn] == TRUE) {
			$argument = "collapse=".urlencode($dn);
			if ($i == count($DNs))
				$last = "last";
			else
				$last = "";
			$icon1 = $last."minus".$selected.".gif";

			if (isset($icons["open_".$group]))
				$icon2 = "open_".$icons[$group];
			else
				if (isset($icons[$group]))
					$icon2 = $icons[$group];
				else
					$icon2 = DEFAULT_ICON;

			$new_link  = "<FONT SIZE=\"-2\">[&nbsp;<A HREF=\"".MAINFILE."?do=choose_entrytype&parent=".urlencode($dn)."\" TARGET=\"right\"><ACRONYM TITLE=\"Create a new entry under this entry\">new</ACRONYM></A>&nbsp;]</FONT>";
		}
		else {
			$argument = "expand=".urlencode($dn);
			if ($i == count($DNs) - 1)
				$last = "last";
			else
				$last = "";
			$icon1 = $last."plus".$selected.".gif";

			if (isset($icons[$group]))
				$icon2 = $icons[$group];
			else
				$icon2 = DEFAULT_ICON;

			$new_link = "";
		}

		if (ENABLE_JAVASCRIPT) {
			$cooljs_tr = "onMouseOver=\"javascript:this.style.backgroundColor='".COLOR_BG1."';\" onClick=\"javascript:this.style.backgroundColor='".COLOR_BG2."';\" onMouseOut=\"javascript:this.style.backgroundColor='#FFFFFF';\"";
			$cooljs_href = "onMouseOver=\"javascript:window.status='".$dn."'; return true;\" onMouseOut=\"javascript:window.status=''; return true;\"";
		}
		echo "<TR VALIGN=\"middle\" ".$cooljs_tr."><TD>".$anchor."<A HREF=\"".TREEFILE."?".$argument."#activeentry\"><IMG SRC=\"".IMAGES_URLPATH."/".$icon1."\" BORDER=\"0\"></A></TD><TD><TABLE BORDER=\"0\" CELLSPACING=\"0\" CELLPADDING=\"0\"><TR><TD><IMG SRC=\"".IMAGES_URLPATH."/".$icon2."\" BORDER=\"0\"></TD><TD NOWRAP><FONT SIZE=\"-1\"><A HREF=\"".MAINFILE."?do=view_entry&entry=".urlencode($dn)."\" TARGET=\"right\" ".$cooljs_href.">".$rdn."</A></FONT>&nbsp;".$new_link."</TD></TR></TABLE></TD></TR>\n";

		if ($_SESSION["expanded"][$dn] == TRUE)
		{
			echo "<TR><TD ALIGN=\"center\"></TD><TD>";
			showContents($ldap_func, $dn);
			echo "</TD></TR>";
		}
	}
	echo "</TABLE>";
}

session_start();

# No ldap_server variable prolly means we're not connected yet
if (!$_SESSION["ldap_server"]) die("Not connected!");

$ldap_func = new LDAPFunc($_SESSION["ldap_server"], $_SESSION["ldap_port"]) or die("Cannot Connect!");
$ldap_func->bind($_SESSION["ldap_binddn"], $_SESSION["ldap_bindpw"]) or die("Can't bind");

$expand		= $HTTP_GET_VARS["expand"];
$collapse	= $HTTP_GET_VARS["collapse"];

if ($expand) $_SESSION["expanded"][$expand] = TRUE;
if ($collapse) unset($_SESSION["expanded"][$collapse]);

require INCLUDE_PATH."/header.inc";

require INCLUDE_PATH."/toolbar.inc";

createIconsHash($entry_types, $icons);

showContents($ldap_func, LDAP_BASEDN);
	
require INCLUDE_PATH."/footer.inc";
?>
